# run using: python test.py
#
#  This script attempts to recreate the Matlab script "test.m" distrbuted with the original release 
#  of the 2019 NASA UQ Challenge Problem.
#

import numpy as np
import matplotlib.pyplot as plt
import os
import csv

# ---------------------------------------------------------------------------------------------------
# Plot the limited number (100) observations of the uncertain subsystem, y(a,e,t)
#
# This is equivalent plotting the data contained in 'D1.mat' datafile in the Matlab version

data = np.genfromtxt('y_D1', delimiter=',')
t = np.genfromtxt('tout', delimiter=",")

plt.plot(t,data)
plt.ylabel('Measured y(t)')
plt.xlabel('Time, [s]')
plt.show(block = False)

#
# ---------------------------------------------------------------------------------------------------
#  Run UQ Challenge Probelm
#
#  The variable casenum is defined in datafile: "casefile.dat"
#
# casenum = 1 call: yfun.m    [obtain realizations of the uncertain subsystem, y(a,e,t)]
# casenum = 2 call: zfun.m    [obtain realizations of the integrated system, z1(a,e,theta,t), z2(a,e,theta,t)]
# casenum = 3 call: gfun.m    [compute the requirements vector g(a,e,theta)]
# casenum = 4 call: yfun.m + zfun.m  [obtain realizations uncertain subsystem and integrated system using a single system command]
# casenum = 5 call: yfun.m + gfun.m  [obtain realizations uncertain subsystem and requirements vector using a single system command]
# casenum = 6 call: zfun.m + gfun.m  [obtain realizations integrated system and requirements vector using a single system command]
# casenum = 7 call: yfun + zfun.m + gfun.m  [obtain realizations of y,z,g using a single system command]
#
# The following command runs the standalone Matlab executable
#
cmd = ' run_nasa_uq_2019.sh /Applications/MATLAB/MATLAB_Runtime/v96 "aleatory.dat" "epistemic.dat" "design.dat" "casefile.dat"'
os.system(cmd)

#
# Read response data from comma-seperated datafiles
#

yout = np.genfromtxt('yout', delimiter=",")
plt.figure()
plt.plot(t,yout)
plt.ylabel('Predicted y(t)')
plt.xlabel('Time, [s]')
plt.show(block = False)

z1out = np.genfromtxt('z1out', delimiter=",")
z2out = np.genfromtxt('z2out', delimiter=",")

plt.figure()
plt.plot(t,z1out)
plt.ylabel('Predicted z_1(t)')
plt.xlabel('Time, [s]')
plt.show(block = False)

plt.figure()
plt.plot(t,z2out)
plt.ylabel('Predicted z_2(t)')
plt.xlabel('Time, [s]')
plt.show(block = False)

plt.show()


